Documentation
¶
Overview ¶
Package tcp adds a TCP traceroute implementation to the agent
Package tcp adds a TCP traceroute implementation to the agent
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type TCPv4 ¶
type TCPv4 struct {
TargetHostname string
TargetIP net.IP
DestPort uint16
NumPaths uint16
MinTTL uint8
MaxTTL uint8
Delay time.Duration // delay between sending packets (not applicable if we go the serial send/receive route)
Timeout time.Duration // full timeout for all packets
// contains filtered or unexported fields
}
TCPv4 encapsulates the data needed to run a TCPv4 traceroute
func (*TCPv4) Close ¶
Close doesn't to anything yet, but we should use this to close out long running sockets when we're done with a path test
func (*TCPv4) Traceroute ¶
func (t *TCPv4) Traceroute() (*payload.NetworkPath, error)
func (*TCPv4) TracerouteSequential ¶
TracerouteSequential runs a traceroute sequentially where a packet is sent and we wait for a response before sending the next packet
Click to show internal directories.
Click to hide internal directories.